@@ -28,6 +28,8 @@
 static struct ide_hw	hw[NR_DRIVES/2];
 static struct ide_drive	drives[NR_DRIVES];
 
+extern char *cmdline;
+
 /*
  * figure out which status register to use for probing
  */
@@ -153,7 +155,7 @@ static int lba_ok(struct ide_drive *drive, struct hd_driveid *id)
 	return 0;
 }
 
-static int idx(unsigned int val, unsigned int *vals)
+static int idx(unsigned int val, const unsigned int *vals)
 {
 	int i;
 
@@ -208,7 +210,7 @@ static void get_speed_params(struct ide_drive *drive, struct hd_driveid *id)
 		 * EIDE DMA
 		 */
 		if (drive->dma == 0 && id->eide_dma_time != 0 && id->eide_dma_time <= 180) {
-			static unsigned int eide_times[] = { 150, 120, 90, 60, 0 };
+			static const unsigned int eide_times[] = { 150, 120, 90, 60, 0 };
 			drive->dma = 1;
 
 			drive->dma_speed = DMA_DMA0 + idx(id->eide_dma_time, eide_times);
@@ -217,7 +219,7 @@ static void get_speed_params(struct ide_drive *drive, struct hd_driveid *id)
 		 * EIDE PIO
 		 */
 		if (eide_pio_cyc_time != 0) {
-			static unsigned int eide_pio_times[] =
+			static const unsigned int eide_pio_times[] =
 				{ 570, 540, 510, 480, 450, 420, 390, 360, 330,
 				  300, 270, 240, 210, 180, 150, 120, 90, 60, 0 };
 
@@ -579,6 +581,11 @@ static int ide_probe(void)
 
 		i = pci_io_read_byte(hw[0].dma_base + 2);
 		pci_io_write_byte(i & ~0x60, hw[0].dma_base + 2);
+		/*
+		 * Linux 2.3 requires the following
+		 * for Promise UDMA33 or UDMA66
+		 */
+		pci_io_write_byte(0x01, hw[0].dma_base + 0x1f);
 
 		base = pci_read_config_long(pci_base, PCI_BASE2) & ~3;
 
@@ -768,6 +775,9 @@ static int ide_load(void)
 
 	printf("Loading %s...", boot_map_file + p[1]);
 
+	if (p[2])
+		cmdline = boot_map_file + p[2];
+
 	copy_map(&map, boot_map_file + p[3]);
 
 	if (read_mapped_file(drive, part_start, &map, (u8 *)load_addr))
