@@ -3,9 +3,6 @@
 int printf(const char *fmt, ...);
 int sprintf(char *buf, const char *fmt, ...);
 int vsprintf(char *buf, const char *fmt, va_list args);
-
-/*
- * function to be called to display printf output
- */
-extern void (*display_fn)(const char *buffer, int len);
-
+int getc(void);
+int getc_timed(int cs);
+int gets(char *, int len);
