@@ -3,11 +3,10 @@
 #include <asm/setup.h>
 
 #define LOAD_ADDR	0x8000
-
-#define ARCH_TYPE 4
-#define CMD_LINE ""
+#define ARCH_TYPE	4
 
 static struct param_struct *params = (struct param_struct *)0x100;
+extern char *cmdline;
 extern int ram_size;
 
 u32	root_dev;
@@ -28,7 +27,7 @@ void boot_kernel(void)
 		       &params->u1.s.video_num_cols,
 		       &params->u1.s.video_num_rows);
 
-	strcpy(params->commandline, CMD_LINE);
+	strcpy(params->commandline, cmdline);
 	((void (*)(int,int))load_addr)(0,ARCH_TYPE);
 }
 
